      SUBROUTINE CNOMST (IACTHR,IACTMN,KOFFSET,KESA,REQUEST)
C***********************************************************************
C                                                                       
C   NAME- CNOMST
C                                                                       
C   LANGUAGE- FORTRAN     TYPE- SUBROUTINE                              
C                                                                       
C   VERSION-  2.00  DATE- 08/29/06  PROGRAMMER- SCHREITZ, R.  EC2200:q
C                                                                       
C   FUNCTION-
C
C     COMPUTES THE SATELLITE-SPECIFIC NOMINAL OR REFERENCE START TIME,
C     IN HOURS AND MINUTES, OF THE RELEVANT 30-MINUTE INGEST CYCLE,
C     USING THE ACTUAL FRAME START TIME, THE SATELLITE-SPECIFIC
C     START TIME OFFSET, AND THE MAXIMUM 'EARLY START' ALLOWANCE.
C
C     STORES THE NOMINAL START TIME IN THE LOCATOR/READER REQUEST
C     FORMAT FOR USE IN GENERATING THE FRAME LABEL.  THE NOMINAL
C     START TIME SERVES AS A USEFUL DESCRIPTOR IN DATABASES DESIGNED
C     ON THE 'SLOT' CONCEPT.
C
C   CALLING SEQUENCE PARAMETERS-
C
C     IACTHR            ACTUAL STARTING HOUR
C     IACTMN            ACTUAL STARTING MINUTE
C     KOFFSET           SATELLITE-SPECIFIC START TIME OFFSET,
C                       IN MINUTES
C
C                         cURRENT VALUES:  -15 FOR GOES-EAST
C                                            0 FOR GOES-WEST
C
C     KESA              MAXIMUM 'EARLY START' ALLOWANCE, IN MINUTES
C
C                         CURRENT VALUE:    -2
C
C     REQUEST           NOMINAL START TIME IN LOCATOR/READER REQUEST
C                       FORMAT
C
C                         TYPICAL REQUEST IN FINAL FORM:  'E2345ZIR'
C
                        CHARACTER*9 REQUEST
C
C   KEY LOCAL PARAMETERS-
C
C     IACTMND           ACTUAL STARTING MINUTES OF DAY
C     IREFMND           REFERENCE STARTING MINUTES OF DAY
C     IREFHR            REFERENCE STARTING HOUR
C     IREFMN            REFERENCE STARTING MINUTE
C
C***********************************************************************
      IREFHR  = 0
      IREFMN  = 0
      REQUEST = ' HHMMZ   '
C
      IACTMND = 60*IACTHR + IACTMN
C
C     IN THE 48 MEMBER SEQUENCE OF ACCEPTED INGEST CYCLE INTERVALS,
C     FIND THE INTERVAL THAT INCLUDES THE SUBMITTED INGEST START TIME.
C
      ISUM00 = KOFFSET + KESA
      ISUM00 = ISUM00 + 30     ! ISUM00 MUST BE POSITIVE.
c
      DO I = 1,48
C
      ISUM30 = ISUM00 + 30
C
        IF (IACTMND.GE.ISUM00.AND.IACTMND.LT.ISUM30) THEN
          IREFMND = ISUM00 - KESA
          IREFHR = IREFMND/60
          IREFMN = IREFMND - 60*IREFHR
          GO TO 10
        ELSE
          ISUM00 = ISUM00 + 30
        END IF
C
      END DO
C
   10 WRITE (REQUEST(03:05),3010) IREFMN + 100
      WRITE (REQUEST(01:03),3010) IREFHR + 100
      WRITE (REQUEST(01:01),3020) ' '
      RETURN
C
 3010 FORMAT (I3)
 3020 FORMAT (A1)
      END
