      SUBROUTINE EXLINES (FNAME,ISTAT)
C***********************************************************************
C
C   NAME- EXLINES
C
C   LANGUAGE- VS FORTRAN  TYPE- SUBROUTINE      COMPUTER- 3090/9000
C
C   VERSION-  0.00  DATE- 03/01/88  PROGRAMMER-  ROBINSON, DIANE
C   VERSION-  0.00  DATE- 04/05/94  PROGRAMMERS- GOCKEL, BRIAN (HSTX)
C                                                AKUNURI, RAMANA (SMSRC)
C   VERSION-  0.00  DATE- 06/28/95  PROGRAMMER-  ROEGNER, TOM (HSTX)
C   VERSION-  0.00  DATE- 12/04/95  PROGRAMMER-  ROEGNER, TOM (HSTX)
C   VERSION-  0.00  DATE- 05/29/96  PROGRAMMER-  GUPTA, SUSHMA (SMSRC)
C   VERSION-  0.00  DATE- 11/14/97  PROGRAMMER-  J. SELEKOF (STC)
C   VERSION-  2.00  DATE- 08/19/06- PROGRAMMER-  SCHREITZ, R.  EC2200
C                         08/29/06
C                   REMOVAL OF FAX/WEFAX PROCESSING, CONVERSION TO AIX,
C                   MODERNIZATION AND/OR SIMPLIFICATION OF LOGIC.
C
C   BACKGROUND-
C
C     THE FEP/AFEP DECOMMUTES THE GVAR DATA STREAM INTO SEPARATE
C     STREAMS, EACH OF WHICH CONTAINS DATA FROM ONE CHANNEL ONLY,
C     AND STORES THESE STREAMS IN SEPARATE FILES.  IT BECOMES
C     CLEAR FROM AN EXAMINATION OF THE GVAR FORMAT AND THE DE-
C     COMMUTATION PROCESS THAT A DATA RECORD IN SUCH A FILE WILL
C     FALL IN ONE OF THE FOLLOWING CATEGORIES:
C
C          BLOCK  1  CHANNEL 4
C          BLOCK  1  CHANNEL 5
C
C          BLOCK  2  CHANNEL 2
C          BLOCK  2  CHANNEL 3
C
C          BLOCK  3  CHANNEL 1
C          BLOCK  4  CHANNEL 1
C          BLOCK  5  CHANNEL 1
C          BLOCK  6  CHANNEL 1
C          BLOCK  7  CHANNEL 1
C          BLOCK  8  CHANNEL 1
C          BLOCK  9  CHANNEL 1
C          BLOCK 10  CHANNEL 1.
C
C     CONSEQUENTLY A FEP/AFEP DATA RECORD CANNOT BE DEFINITIVELY
C     LABELED SOLELY BY ITS BLOCK ID OR SOLELY BY ITS CHANNEL ID.
C
C     NAMES OF PARAMETERS RELATED UNIQUELY TO THE DOCUMENTATION
C     RECORD PRODUCED BY THE FEP/AFEP TYPICALLY HAVE THE POSTFIX
C     '0' (E.G. IREC0), WHERE '0' INDICATES BLOCK 0.
C
C     NAMES OF PARAMETERS RELATED UNIQUELY TO THE DATA RECORD
C     PRODUCED BY THE FEP/AFEP TYPICALLY HAVE THE POSTFIX
C     'W' (E.G. IRECW), WHERE 'W' SERVES AS A SEQUENCE OF TWO
C     PLACEHOLDERS FOR 'B' AND 'C', RESPECTIVELY, WHERE 'B' AND 'C',
C     WHICH ARE UNDEFINED IN THE GENERIC PARAMETER NAME, REPRESENT
C     BLOCK AND CHANNEL.
C
C   FUNCTION-     
C
C     PERFORMS PRELIMINARY VALIDITY CHECKING OF A DATA RECORD.
C
C     DETERMINES THE NUMBER OF LINES IN THE DATA RECORD AND THE NUMBER	
C     SAMPLES IN EACH LINE AND TRANSFERS THE LINES TO A WRITE BUFFER.
C
C     WRITES, FOR EVERY 100TH DATA RECORD, A MESSAGE THAT SHOWS
C     THE BASE 16 VALUES THAT GO INTO THE EXTRACTION PROCESS AND
C     THE BASE 10 VALUES THAT COME OUT OF IT.
C
C   CALLING SEQUENCE PARAMETERS-
C
C     VARIABLE   TYPE  I/O  FUNCTION
C     --------   ----  ---  --------
C     FNAME      C*44  I--  FRAME NAME (E. G. GOS.IR4.GM ... )
                            CHARACTER*44 FNAME
C     ISTAT      I*4        SUBROUTINE RETURN STATUS (NOT USED)
                            INTEGER*4 ISTAT
C     IFLAG      I*4        IR DATA STATUS (NOT USED)
C                           0 - GOOD IR1 OR IR2
C                           1 - BAD IR1 AND IR2
                            INTEGER*4 IFLAG
C
C   COMMON AREA PARAMETERS-
C
      INCLUDE 'ingest.i'
      INCLUDE 'control.i'
      INCLUDE 'unpacked.i'
      INCLUDE 'rconst.i'
C
C   LOCAL PARAMETERS-
C
C     VARIABLE   TYPE  I/O  FUNCTION
C     --------   ----  ---  --------
C     CHAN       C*3        CHANNEL (VIS, IR2, IR3, ... )
                            CHARACTER*3 CHAN 
C     SCID       C*2        SPACECRAFT ID (GK, GL, GM, ... ) 
                            CHARACTER*2 SCID
C                           SUBROUTINE EXLINES EXTRACTS THE FOLLOWING
C                           3 PARAMETERS FROM THE LINE DOCUMENTATION:
C     KRISCT     I*4        RELATIVE OUTPUT SCAN COUNT SINCE THE START
C                           OF THE IMAGING FRAME
C     NUMPIX     I*4        NUMBER OF PIXELS IN THE DETECTOR DATA
C                           RECORD
C     LWORDS     I*4        NUMBER OF 10-BIT WORDS IN THE DETECTOR
C                           RECORD, FROM THE FIRST WORD OF THE LINE
C                           DOCUMENTATION TO THE LAST WORD IN 
C                           THE DETECTOR DATA PARTITION
C
C                           THE FOLLOWING 3 PARAMETERS ARE NOT USED.
C     CPUS       R*8        CPU TIME (STARTING)
                            REAL*8 CPUS
C     CPUE       R*8        CPU TIME (ENDING)
                            REAL*8 CPUE
C     CPUTOT     R*8        CPU TIME (TOTAL ELAPSED)
                            REAL*8 CPUTOT
C
C     LINE1_10   I*4        POINTER TO THE FIRST 10-BIT WORD OF
C                           THE LEFT-SIDE DETECTOR DATA STREAM 
C     LINE2_10   I*4        POINTER TO THE FIRST 10-BIT WORD OF
C                           THE RIGHT-SIDE DETECTOR DATA STREAM
C     LINE1_8    I*4        POINTER TO THE FIRST 8-BIT WORD OF
C                           THE LEFT-SIDE DETECTOR DATA STREAM 
C     LINE2_8    I*4        POINTER TO THE FIRST 8-BIT WORD OF 
C                           THE RIGHT-SIDE DETECTOR DATA STREAM
C
C   BLOCK DATA- NONE
C                                                                      X                 
C   SUBPROGRAMS CALLED-
C     BRPK
C
C   EXIT STATES- NONE
C
C   RESTRICTIONS- NONE
C
C   ATTRIBUTES- SERIALLY REUSABLE
C
C   COMMENTS
C
C***********************************************************************
c
C     STATEMENT FUNCTION REQUIRED FOR BRPK:
      IX8(I) = ((I - 1)*8) + 1    ! BYTE ADDRESS TO  1-BIT WORD ADDRESS
C
      KHO = 0
      KLO = 0
      ISTAT = 0
      IFLAG = 0

      KPRINT = .FALSE.
      IF (IR0.EQ.100) KPRINT = .TRUE.
C
      CHAN = FNAME(05:07)
      SCID = FNAME(10:11)
C
C     DETERMINE THE NUMBER OF LINES PER DATA RECORD.
      IF ((CHAN.EQ.'IR3'.AND.(SCID.EQ.'GK'.OR.SCID.EQ.'GL')).OR.
     |    (CHAN.EQ.'IR6'.AND.(SCID.EQ.'GM'.OR.SCID.EQ.'GN'))) THEN
      NUMDET = 1
      ELSE
      NUMDET = 2
      END IF
C 
C     IN THE RETRIEVED RECORD, THE DETECTOR LINE DOCUMENTATION FOLLOWS
C     A SEQUENCE OF THREE IDENTICAL BLOCK HEADER RECORDS EACH OF WHICH
C     CONSISTS OF 30 8-BIT WORDS.  THE DETECTOR LINE DOCUMENTATION
C     CONSISTS OF 16 10-BIT WORDS.  SINCE THE MAXIMUM VALUE THAT CAN
C     BE REPRESENTED IN A 10-BIT WORD IS 1023, SOME OF THE VALUES TO
C     BE REPRESENTED REQUIRE TWO CONSECUTIVE 10-BIT WORDS.
C
      CALL BRPK(BUFX,10,73,LINDOC,16,1,16)
      KHO = LINDOC(6)
      KLO = LINDOC(7)
      KRISCT = IOR(ISHFT(KHO,10),KLO)
      KHO = LINDOC(10)
      KLO = LINDOC(11)
      NUMPIX = IOR(ISHFT(KHO,10),KLO)
      KHO = LINDOC(12)
      KLO = LINDOC(13)
      LWORDS = IOR(ISHFT(KHO,10),KLO)
C
      IF (KPRINT) PRINT 3510, KRISCT,NUMPIX,LWORDS
C
C***********************************************************************
C
C     SPECIFY THE RESPECTIVE STARTS OF THE LEFT-SIDE AND RIGHT-SIDE
C     DETECTOR DATA STREAMS IN 10-BIT WORD COUNTS.
C
C                SKIP OVER       SKIP OVER
C                                LEFT
C                HEADER          DETECTOR LINE
C                                DOCUMENTATION
C
C                3 X 30
C                8-BIT
C                WORDS
C
C                72              16
C                10-BIT          10-BIT
C                WORDS           WORDS
C
      LINE1_10 = 72            + 16            + 1
C
C                SKIP OVER       SKIP OVER       SKIP OVER
C                                LEFT            RIGHT
C                HEADER          DETECTOR LINE   DETECTOR LINE
C                                RECORD          DOCUMENTATION
C
C                3 X 30
C                8-BIT
C                WORDS
C
C                72              LWORDS          16
C                10-BIT          10-BIT          10-BIT
C                WORDS           WORDS           WORDS
C
      LINE2_10 = 72            + LWORDS        + 16            + 1
C
C***********************************************************************
C
      LINE1_8 = 90 + 20 + 1
C
      I_LW_8  = (LWORDS/4  )*5
C
      LINE2_8 = 90 + I_LW_8 + 20 + 1
C
      IF(NUMPIX.GE.1 .AND. NUMPIX.LE.13222) THEN
C
        IF(NUMDET==1) THEN
C
C         THERE IS ONLY ONE LINE TO UNPACK ...
C
C         INITIALIZE SENSOR DATA BEGINNING AT THE END
C         OF THE LINE OF DATA
          CALL BRPK(BUFX,10,89,IRDAT(1,1),16,1,NUMPIX)
          DO INDX = NUMPIX+1,13222
            IRDAT(INDX,1) = 1
          END DO    
C
        ELSEIF(NUMDET==2) THEN
C
C         THERE ARE TWO LINES TO UNPACK ...
C
C***********************************************************************
C
          IF (KPRINT) THEN
            PRINT 3710, LINE1_10
            IIBASE = LINE1_8 - 1
            DO INDEX = 1,14
              PRINT 3910, (BUFX(II:II+3),II=IIBASE+1,IIBASE+80,4)
              IIBASE = IIBASE + 500
            END DO
          END IF
C
          CALL BRPK (BUFX,10,LINE1_10,IRDAT(1,1),16,1,NUMPIX)
C
          IF (KPRINT) THEN
            IIBASE = 0
            DO INDEX = 1,14
              PRINT 3920, (IRDAT(II,1),II=IIBASE+1,IIBASE+20)
              IIBASE = IIBASE + 400
            END DO
          END IF
C
C***********************************************************************
C
          IF (KPRINT) THEN
            PRINT 3720, LINE2_10
            IIBASE = LINE2_8 - 1
            DO INDEX = 1,14
              PRINT 3930, (BUFX(II:II+3),II=IIBASE+1,IIBASE+80,4)
              IIBASE = IIBASE + 500
            END DO
          END IF
C
          CALL BRPK (BUFX,10,LINE2_10,IRDAT(1,2),16,1,NUMPIX)
C
          IF (KPRINT) THEN
            IIBASE = 0
            DO INDEX = 1,14
              PRINT 3940, (IRDAT(II,2),II=IIBASE+1,IIBASE+20)
              IIBASE = IIBASE + 400
            END DO
          END IF
C
C***********************************************************************
C
          DO INDX = NUMPIX+1,13222
            IRDAT(INDX,1) = 1
            IRDAT(INDX,2) = 1
          END DO   
        END IF
C
      ELSE
C
C  SET RETURN STATUS TO INDICATE ABNORMAL CONDITION.
C
      ISTAT = -1
      PRINT 3950
      GO TO 999
      END IF
C
C  SET RETURN STATUS TO INDICATE SUCCESSFUL COMPLETION.
C
      ISTAT=0

  999 RETURN
C
 3510 FORMAT (1X,  'EXLINES: DETECTOR LINE DOCUMENTATION: ',
     |             'KRISCT,NUMPIX,LWORDS',3I6)
 3710 FORMAT (1X,  'EXLINES LINE1_10:',I5)
 3720 FORMAT (1X,  'EXLINES LINE2_10:',I5)
 3910 FORMAT (3(1x,'EXLINES M10:',10(1x,4Z2)/))
 3920 FORMAT (1X,  'EXLINES M20:',20I5)
 3930 FORMAT (3(1x,'EXLINES M30:',10(1x,4Z2)/))
 3940 FORMAT (1X,  'EXLINES M40:',20I5)
 3950 FORMAT (1X,  'EXLINES: RETRIEVED DETECTOR SAMPLE COUNT ',
     |             'OUT OF RANGE')

C
       END
