#!/bin/bash
#
# Script Name: hist.sh
#
# Usage: hist.sh $1 $2
#     $1 = "00Z" or "12Z"
#     $2 = "EAST" or "WEST"
#
# Example: hist.sh 00Z EAST
#
# This script allocates data sets and executes the load module "hist"
# to produce histograms using the GOES East or GOES West satellite.
# The script is run four times daily; once in the morning (at 12Z)
# for each of the two satellites, and once in the evening (at 00Z)
# for each of the two satellites.
#
/bin/date
yymmdd=`date '+%y%m%d'`
echo "date=$yymmdd"
#
export retcode=0
#
# ANCHOR=/   /    
#
# EXamine positional parameters.
#
if [ $# -ne 2 ]; then
     echo "Enter Parameter 1: 00Z or 12Z"
     echo "Enter Parameter 2: EAST or WEST"
     retcode=99
     exit $retcode
fi
echo $1
echo $2
#
# Test parameter 1.
#
if   [ "$1" != 00Z ]; then
if   [ "$1" != 12Z ]; then
     echo "Command line parameter 1 must be 00Z or 12Z"
     retcode=99
     exit $retcode
fi
fi
# Use parameter 1 to define xxZ and NOTxxZ.
#
     xxZ=$1
#
if   [ "$xxZ" = 00Z ]; then NOTxxZ=12Z
fi
if   [ "$xxZ" = 12Z ]; then NOTxxZ=00Z
fi 
echo $xxZ
echo $NOTxxZ
#
# Test parameter 2.
#
if   [ "$2" != EAST ]; then
if   [ "$2" != WEST ]; then
     echo "Command line parameter 2 must be EAST or WEST"
     retcode=99
     exit $retcode
fi
fi
# Use parameter 2 to define e_w and east_west.
#
if   [ "$2" = EAST ]; then
     e_w=e
     east_west=east
elif [ "$2" = WEST ]; then
     e_w=w
     east_west=west
fi
echo $e_w
echo $east_west
#
#    Signal execution of program and store command line parameters.
echo $1 $2 > $ANCHOR/apps/goes/hist/cdata/$xxZ.$east_west.running
#
export IFPRNT
export IFRNID
export IFINPT
export IFPCRD
export IFPCR2
export IOMAIN
export IOTMP1
export IOTMP2
export IOTMP3
export IOTMP4
export IOT1FN
export IOT2FN
export IOT3FN
export IOT4FN
export XLFRTEOPTS="unit_vars=yes"
export XLFUNIT_70="$ANCHOR/apps/goes/wlr/cdata/ft70.v18vnn.satellite.constellation.table.Wg15_Eg13"
export XLFUNIT_79="$ANCHOR/apps/goes/monan/cdata/ft79.system.clock.override.rsect"
export XLFUNIT_80="$ANCHOR/apps/goes/wlr/cdata/ft80.v18vnn.sk.db.pathnames.11"
export XLFUNIT_90="$ANCHOR/apps/goes/wlr/cdata/ft90.v14vnn.lp.db.frameformats"
#
t1=tmp1
t2=tmp2
t3=tmp3
t4=tmp4
#
IFPRNT="$ANCHOR/apps/goes/histdata/$yymmdd.$xxZ.$east_west.$$.IFPRNT"
IFRNID="$ANCHOR/apps/goes/hist/cdata/$xxZ.$east_west.running"
IFINPT="$ANCHOR/apps/goes/hist/cdata/$xxZ.$east_west.range"
IFPCRD="$ANCHOR/apps/goes/hist/cdata/$east_west.8x6.candidate.pics"
IFPCR2="$ANCHOR/apps/goes/hist/cdata/$east_west.8x1.selected.pics"
IOMAIN="$ANCHOR/apps/goes/histdata/$east_west.weekly"
IOTMP1="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t1"
IOTMP2="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t2"
IOTMP3="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t3"
IOTMP4="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t4"
IOT1FN="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t1.finalname"
IOT2FN="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t2.finalname"
IOT3FN="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t3.finalname"
IOT4FN="$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t4.finalname"   
#
echo $IFPRNT
echo $IFRNID
echo $IFINPT
echo $IFPCRD
echo $IFPCR2
echo $IOMAIN
echo $IOTMP1
echo $IOTMP2
echo $IOTMP3
echo $IOTMP4
echo $IOT1FN
echo $IOT2FN
echo $IOT3FN
echo $IOT4FN
#
#    Delete old output listings.
     find $ANCHOR/apps/goes/histdata -type f -name '*.std.out' -mtime +5 -exec rm {} \;
     find $ANCHOR/apps/goes/histdata -type f -name '*.IFPRNT'  -mtime +5 -exec rm {} \;
#
#    Test for conflict:
#       12Z submitted with 00Z running or 
#       00Z submitted with 12Z running.
     if [ -f "$ANCHOR/apps/goes/hist/cdata/$NOTxxZ.$east_west.running" ]; then
     $ANCHOR/apps/common/bin/op_msg "$xxZ RUN ATTEMPTED DURING EXECUTION OF $NOTxxZ RUN."
     $ANCHOR/apps/common/bin/op_msg "$xxZ RUN TERMINATED.  NOTIFY PROGRAM SPONSOR."    
     rm $ANCHOR/apps/goes/hist/cdata/$xxZ.$east_west.running
     rm $ANCHOR/apps/goes/hist/cdata/$NOTxxZ.$east_west.running
     retcode=99
     exit $retcode
     fi
#
#    Store database anchor for use by program.
#
distdir=$ANCHOR/data/GOES/hist
export filescopied=0
#
out="$ANCHOR/apps/goes/histdata/$yymmdd.$xxZ.$east_west.$$.std.out"
$ANCHOR/apps/goes/hist/bin/hist.bin 1> $out
#
#    Save completion code provided internally by exit_(xx).
     compcode=$?
#
if [ $compcode != "0" ]
then
   $ANCHOR/apps/common/bin/op_msg "An input/output message occurred; See IFPRNT
   file."
   echo " Run ended abnormally!" >> $out
   retcode=99
else
#  Retrieve names for histogram files to be distributed.
   fn1="$(cat $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t1.finalname)"
   fn2="$(cat $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t2.finalname)"
   fn3="$(cat $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t3.finalname)"
   fn4="$(cat $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t4.finalname)"
   echo $fn1 >> $out
   echo $fn2 >> $out
   echo $fn3 >> $out
   echo $fn4 >> $out

   if [ -f "$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t1" ]
   then
   chmod o-w $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t1
   mv $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t1 $distdir/$fn1
   let filescopied+=$?
   fi
   if [ -f "$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t2" ]
   then
   chmod o-w $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t2
   mv $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t2 $distdir/$fn2
   let filescopied+=$?
   fi
   if [ -f "$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t3" ]
   then
   chmod o-w $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t3
   mv $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t3 $distdir/$fn3
   let filescopied+=$?
   fi
   if [ -f "$ANCHOR/apps/goes/histdata/usr.jj.$e_w$t4" ]
   then
   chmod o-w $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t4
   mv $ANCHOR/apps/goes/histdata/usr.jj.$e_w$t4 $distdir/$fn4
   let filescopied+=$?
   fi

   if [ -f "$ANCHOR/apps/goes/histdata/$east_west.weekly" ]
   then
   chmod o-w $ANCHOR/apps/goes/histdata/$east_west.weekly
   cp $ANCHOR/apps/goes/histdata/$east_west.weekly \
               $distdir/goeshist.$east_west.weekly
   let filescopied+=$?
   fi

   if [ $filescopied -eq 0 ] ; then
        $ANCHOR/apps/common/bin/dist_file "$distdir/$fn1"
        let filescopied+=$?
        $ANCHOR/apps/common/bin/dist_file "$distdir/$fn2"
        let filescopied+=$?
        $ANCHOR/apps/common/bin/dist_file "$distdir/$fn3"
        let filescopied+=$?
        $ANCHOR/apps/common/bin/dist_file "$distdir/$fn4"
        let filescopied+=$?
        $ANCHOR/apps/common/bin/dist_file "$distdir/goeshist.$east_west.weekly"
        let filescopied+=$?
        if [ $filescopied -ne 0 ] ; then
             $ANCHOR/apps/common/bin/op_msg "Distribution failed"
             retcode=99
        fi
   else
        $ANCHOR/apps/common/bin/op_msg "Error copying files"
        $ANCHOR/apps/common/bin/op_msg "Distribution skipped"
        retcode=99
   fi
fi
   rm $ANCHOR/apps/goes/hist/cdata/$xxZ.$east_west.running
   exit $retcode
