      FUNCTION KFRAME (NSID,SPOS,INGTYP)
C***********************************************************************
C
C   NAME- KFRAME
C
C   LANGUAGE- VS FORT     TYPE- FUNCTION
C
C   VERSION-  1.04  DATE- 01/23/96  PROGRAMMER- SCHREITZ, R.  EC1300
C   VERSION-  1.10  DATE- 05/19/03  PROGRAMMER- SCHREITZ, R.  EC1300
C                   REVISED TO ACCOMMODATE THE FOLLOWING IMAGERY:
C                   4 KM X 4 KM CHANNEL 3 DATA FROM GOES-M AND BEYOND
C                   4 KM X 4 KM CHANNEL 6 DATA FROM GOES-O AND BEYOND.
C   VERSION-  2.00  DATE- 08/29/06  PROGRAMMER- SCHREITZ, R.  EC2200
C   VERSION-  4.02  DATE- 05/21/10- PROGRAMMER- SCHREITZ, R.  EC2200
C                           /  /
C                   RE-DEFINITION OF WAVELENGTH CODES TO 'V' AND 'I'.
C
C   FUNCTION-
C
C     COMPUTES A FRAME FORMAT POINTER, GIVEN THE SATELLITE ID,
C     THE SATELLITE POSITION, AND THE INGEST TYPE.
C
C     THE FRAME FORMAT POINTER INDICATES THE APPROPRIATE ARRAY ELEMENT
C     IN THE ONE DIMENSIONAL ARRAYS IN COMMON AREAS LFORM AND PFORM.
C     THESE ARRAYS DESCRIBE THE LOGICAL AND PHYSICAL FORMATS,
C     RESPECTIVELY, OF THE VARIOUS FRAMES TO BE STORED IN THE IMAGE
C     DATABASE.
C
C     CONVERTS INGEST TYPE 'R' TO INGEST TYPE 'N'.
C     CONVERTS INGEST TYPE 'Z' TO INGEST TYPE 'S'.
C
C   CALLING SEQUENCE PARAMETERS-
C
C     NSID    I*4  I--  NUMERICAL SATELLITE ID (8, 9, 10,...)
                        INTEGER*4 NSID
C     SPOS    C*4  I--  SATELLITE POSITION ('EAST','WEST',...)
                        CHARACTER*4 SPOS
C     INGTYP  C*4  IO-  INGEST TYPE ('N','S','R','Z')
                        CHARACTER*4 INGTYP
C
C   LOCAL PARAMETERS-
C
C     WVLN    C*1       WAVELENGTH CODE  ('V','I') 
                        CHARACTER*1 WVLN
C     CHAN    C*1       EXTRACTED IR CHANNEL ('2','3','4',...)
                        CHARACTER*1 CHAN
C     ICHAN   I*4       EXTRACTED CHANNEL (1  ,2  ,3,  4, ...)
C
C***********************************************************************
C
C     DEFINE BASE.
      KFRAME = 12
C
C     TEST FOR FULL DISK FRAME.
  10  IF (INGTYP(4:4).EQ.'F')      GO TO 30
C
C     TEST FOR UPPER FRAME RAPID SCAN MODE.
      IF (INGTYP(4:4).EQ.'R') THEN
          INGTYP(4:4)  = 'N'           
                                   KFRAME = KFRAME + 30
                                   GO TO 30
      ENDIF
C
C     TEST FOR LOWER FRAME RAPID SCAN MODE.
      IF (INGTYP(4:4).EQ.'Z') 
     1    INGTYP(4:4)  = 'S'
C
C     TEST FOR UPPER FRAME.
      IF (INGTYP(4:4).EQ.'N')      KFRAME = KFRAME + 20
C
C     TEST FOR LOWER FRAME.
      IF (INGTYP(4:4).EQ.'S')      KFRAME = KFRAME + 40
C
C     TEST FOR VALID FRAME CODE.
      IF (KFRAME.EQ.12) THEN
      WRITE(6,*)'****** DATA SET IS NOT CLASSIFIED FOR WINDS ******'
      GO TO 990
      ENDIF
C
C     TEST FOR WEST SPACECRAFT.
   20 IF (SPOS.EQ.'WEST')          KFRAME = KFRAME + 10
C
C     DETERMINE CHANNEL.
C
C     EXTRACT WAVELENGTH CODE.
   30 WVLN = INGTYP(1:1)
      IF (WVLN.EQ.'V') THEN
      ICHAN = 1
      ELSE
C     EXTRACT IR CHANNEL.    
      CHAN = INGTYP(3:3)
      ICHAN = ICHAR(CHAN) - 48
      ENDIF
C
      KFRAME = KFRAME + 2 + ICHAN
      IF ((ICHAN.EQ.3.AND.NSID.GE.12).OR.ICHAN.GT.3)
     #                             KFRAME = KFRAME + 1
      IF ((ICHAN.EQ.6.AND.NSID.GE.14).OR.ICHAN.GT.6)
     #                             KFRAME = KFRAME + 1
C
  990 RETURN
      END
