      SUBROUTINE PRDB (FTYPE,SCNNO,NLINEE,IOE)
C***********************************************************************
C
C   NAME- PRDB / WSCAN                 PRODUCT SYSTEM: WINDS
C
C   LANGUAGE- VS FORTRAN  TYPE- SUBROUTINE      COMPUTER- IBM 3090
C
C   VERSION-  0.00  DATE- 09/11/87- PROGRAMMERS- D. ROBINSON  (NOAA)
C                         06/23/98               N. WHITE     (GSC)
C                                                B. GOCKEL    (HSTX)
C                                                R. SCHREITZ  EC1300
C                                                R. AKUNURI   (SMSRC)
C                                                T. ROEGNER   (HSTX)
C
C   VERSION-  2.00  DATE- 08/19/03- PROGRAMMER-  R. SCHREITZ  EC1300-
C                         08/29/06                            EC2200
C                   REMOVAL OF FAX/WEFAX PROCESSING, CONVERSION TO AIX,
C                   MODERNIZATION AND/OR SIMPLIFICATION OF LOGIC.
C
C   VERSION-  4.03  DATE- 04/27/11  PROGRAMMER-  R. SCHREITZ  EC2200 
C                   REVISION TO PROCESS CHANNELS 2,3,5,6 WITHOUT
C                   ENHANCEMENT.
C
C     THIS SUBROUTINE DRAWS EXTENSIVELY FROM AND REPLACES A SET OF
C     SIX SUBROUTINES WHICH GRADUALLY EVOLVED OVER A PERIOD OF MORE
C     THAN 10 YEARS.  THE AUTHORS OF THESE EARLIER SUBROUTINES AND
C     THE PERSONS WHO SUBSEQUENTLY CONTRIBUTED TO THEM ARE LISTED
C     ABOVE.
C
C   FUNCTION-
C
C     BUILDS THE LOGICAL RECORD IN THE GOES IMAGER DATABASE FOR 
C     A GIVEN SCAN S AND A GIVEN CHANNEL C.
C
C     - BUILDS THE DATABASE SCAN DOCUMENTATION RECORD.
C
C     - USES, IF APPROPRIATE, SUBROUTINE SCALE AND AN EXTERNAL LOOKUP 
C       TABLE TO CONVERT CHANNEL C SENSOR DATA FOR THE DATABASE TO 
C       A MORE CONVENIENT FORM.
C
C     - USES SUBROUTINE WLINE TO WRITE THE DATABASE SCAN DOCUMENTATION
C       RECORD AND THE ASSOCIATED CHANNEL C SENSOR DATA, IN ITS 
C       ORIGINAL FORM OR IN ITS CONVERTED FORM, LINE-BY-LINE, IN 
C       THE COMPACT, PERFORMANCE-OPTIMIZED DATABASE FORMAT.
C
C     EACH FULL RESOLUTION LOGICAL RECORD CONSISTS OF THE DATABASE 
C     SCAN DOCUMENTATION RECORD FOR SCAN S FOLLOWED K LINES OF LENGTH L
C     OF ASSOCIATED CHANNEL C SENSOR DATA, WHERE K IS THE NUMBER OF 
C     CHANNEL C SENSORS OFFERED BY THE SATELLITE AND L IS THE NUMBER OF 
C     SAMPLES IN A FIRST-SAMPLE-TO-LAST-SAMPLE RANGE SPECIFIED IN AN 
C     EXTERNAL DATABASE DESCRIPTOR SET.   
C
C     EACH REDUCED RESOLUTION LOGICAL RECORD CONSISTS OF THE DATABASE
C     SCAN DOCUMENTATION RECORD FOR SCAN S FOLLOWED K/A LINES OF 
C     LENGTH L/B OF ASSOCIATED CHANNEL C SENSOR DATA, WHERE A AND B 
C     ARE APPROPRIATE POWERS OF 2.  
C
C     CONSTRUCTION OF AN N-LINE LOGICAL RECORD REQUIRES N CALLS TO
C     SUBROUTINE WLINE.  THE SCAN DOCUMENTATION PROVIDED IN THE LAST
C     OF THE N CALLS WILL BE THE SCAN DOCUMENTATION THAT APPEARS IN
C     THE FINAL VERSION OF THE LOGICAL RECORD.
C
C     IN THE COMMENTS THAT FOLLOW, WHEN RESOLUTION IS SPECIFIED BY
C     THE SINGLE TERM 'I KM', WHERE I = 1,2,4,8,..., THE TERM SHOULD
C     BE INTERPRETED AS AN ABBREVIATION FOR THE TERM 'I KM X I KM'
C     IN WHICH THE FIRST AND SECOND DESCRIPTORS REFER, RESPECTIVELY,
C     TO THE VERTICAL (N/S) AND HORIZONTAL (E/W) RESOLUTIONS.
C
C     CURRENTLY THIS SUBROUTINE IS USED ONLY WITH 4 KM X 4 KM DATA.
C
C     THE SAMPLING DENSITY ASSOCIATED WITH I KM X '4 KM' FRAMES
C     RESULTS IN AN ACTUAL HORIZONTAL (E/W) RESOLUTION OF 2.3 KM.
C
C     THE NORMAL AND MAXIMUM LINE LENGTHS FOR AN I KM X 4 KM FULL DISK
C     FRAME ARE, RESPECTIVELY, 4800 ELEMENTS AND 5500 ELEMENTS.
C
C     LINE LENGTHS APPROACHING THE MAXIMUM MAY BE ENCOUNTERED DURING
C     POST-LAUNCH OR POST-MANEUVER ACTIVITIES.
C
C     IN THE CURRENT SCENARIO, FOR ALL CHANNELS EXCEPT 3 AND 6,
C        K IS 2 AND THE RESULTING VERTICAL (N/S) RESOLUTION IS 4 KM.
C     FOR CHANNEL 3, IF THE SPACECRAFT IS GOES-11 OR EARLIER,
C        K IS 1 AND THE RESULTING VERTICAL (N/S) RESOLUTION IS 8 KM.
C     FOR CHANNEL 6, IF THE SPACECRAFT IS GOES-13 OR EARLIER,
C        K IS 1 AND THE RESULTING VERTICAL (N/S) RESOLUTION IS 8 KM.
C
C     FOR BREVITY, THE TERM 'UR' WILL BE USED FOR 'MICRORADIANS'.
C
C     AT GEOSTATIONARY ALTITUDE, AN ANGLE OF 28 UR CORRESPONDS TO
C     A DISTANCE OF APPROXIMATELY 1 KM AT THE SUBSATELLITE POINT
C     ON THE SURFACE OF THE EARTH.
C
C     SPACECRAFT IN THE GOES GVAR SERIES OFFER 1 KM VISIBLE FRAMES,
C     GENERATED BY EIGHT SENSORS WHOSE RESPECTIVE FIELDS OF VIEW
C     COVER, IN EQUAL INCREMENTS, A RANGE EXTENDING FROM 112 UR ABOVE
C     THE SCAN PLANE TO 112 UR BELOW THE SCAN PLANE.  A LOGICAL RECORD
C     IN A 1 KM VISIBLE FRAME CONSISTS OF THE SCAN DOCUMENTATION
C     FOLLOWED BY EIGHT LINES OF SENSOR DATA AND NORMALLY REQUIRES
C               150 + 8*4*4800*10/8 = 192150 BYTES.
C     THE MAXIMUM PHYSICAL BLOCK SIZE FOR AN IBM 3380 DASD IS
C                                      47476 BYTES.
C     SUBROUTINE WLINE AND ITS ASSOCIATED WRITER/LOCATOR/READER UTILIZE
C     A "MACROBLOCK" CONCEPT IN WHICH THE ACCESS LOGIC VIEWS A SEQUENCE
C     OF B PHYSICAL BLOCKS AS A PHYSICAL "MACROBLOCK".  THIS CONCEPT
C     ALLOWS A DATABASE DESIGNER TO SPECIFY AN OPTIMAL PHYSICAL
C     BLOCK SIZE (E. G. 23475 BYTES FOR AN IBM 3380 DASD) AND A VALUE
C     OF B LARGE ENOUGH SO THAT A PHYSICAL "MACROBLOCK" CAN CONTAIN
C     THE LARGEST REQUIRED LOGICAL RECORD/LOGICAL BLOCK.
C
C     SUBROUTINE PRDB CAN BE USED WITH GVAR DATA AT THE MAXIMUM
C     RESOLUTION, 1 KM X 1 KM.  AT THIS RESOLUTION, THE LINE BUFFER
C     SHOULD BE CAPABLE OF HOLDING 4*5500= 22000 ELEMENTS.
C
C   CALLING SEQUENCE PARAMETERS-
C
C     FTYPE    C*4      FRAME TYPE     (VISF,VISN,VISS,...) (FROM FNAME)
                        CHARACTER*4 FTYPE
C     SCNNO   I*4  I--  SCAN NUMBER
                        INTEGER*4 SCNNO
C     NLINEE  I*4  -O-  LINE NUMBER IS OUT OF ALLOWABLE RANGE
                        INTEGER*4 NLINEE
C     IOE     I*4  -O-  IO ERROR
                        INTEGER*4 IOE
C
C   COMMON AREA PARAMETERS-
C
      INCLUDE 'ingest.i'
      INCLUDE 'control.i'
      INCLUDE 'lb.i'
      INCLUDE 'unpacked.i'
      INCLUDE 'frame.i'
      INCLUDE 'lform.i'
      INCLUDE 'db.i'
      INCLUDE 'iostat.i'
      INCLUDE 'ab211275.i'
      INCLUDE 'statushb.i'
C
C   LOCAL PARAMETERS-
C
C     SCANDOC  C*150    SCAN DOCUMENTATION
                        CHARACTER*150 SCANDOC

C     VS      L*4       VISIBLE DATA FLAG
C                       .TRUE. = VISIBLE DATA TO BE PROCESSED
                        LOGICAL*4 VS
C     IR      L*4       IR DATA FLAG
C                       .TRUE. = IR DATA TO BE PROCESSED
                        LOGICAL*4 IR
C     IR4     L*4       IR4 DATA FLAG
C                       .TRUE. = IR4 DATA TO BE PROCESSED
                        LOGICAL*4 IR4
C     IFIRST  I*4       FIRST SAMPLE ON OUTPUT LINE
                        INTEGER*4 IFIRST
C
C     ILAST   I*4       LAST SAMPLE ON OUTPUT LINE
                        INTEGER*4 ILAST
C
C     JINC    I*4       BLOCK INCREMENT CORRESPONDING TO REQUESTED
C                       VERTICAL RESOLUTION
                        INTEGER*4 JINC
C
C     IINC    I*4       SAMPLE INCREMENT CORRESPONDING TO REQUESTED
C                       HORIZONTAL RESOLUTION
                        INTEGER*4 IINC
C
C     LINELEN I*4       NUMBER OF PIXELS REQUESTED FROM EACH DETECTOR
                        INTEGER*4 LINELEN
C
C     FFILL   I*2       FILL HALFWORD
                        INTEGER*2 FFILL
C
C     KREQ    I*4       POINTER - INDICATES DATABASE PRODUCT   (1 - 8)
C                       ALSO USED AS AN OFFSET FROM KUN TO INDICATE
C                       UNIT NUMBER TO BE ASSOCIATED WITH DATA SET
C                       RESERVED FOR DATABASE PRODUCT
C                       (SET TO PERMANENTLY TO 1 FOR THIS PROGRAM)
C     ILB     I*4       LINE BUFFER INDEX
C     I       I*4       DATA BUFFER INDEX
C     J       I*4       DATA BUFFER INDEX
C     IX      I*4       WORD SIZE IN BYTES OF DATA WORDS IN LINEBUF
C                       (2)
C     NLINE   I*4       NUMBER OF THE LINE TO BE WRITTEN
C     NLINEE  I*4       ERROR CODE - A NEGATIVE VALUE INDICATES
C                       THAT THE NUMBER OF THE LINE TO BE WRITTEN
C                       IS OUT OF RANGE
C     HKAISCT           ABSOLUTE SCAN NUMBER
                        INTEGER*2 HKAISCT
C     KAISCT            ABSOLUTE SCAN NUMBER
C     KRISCT            RELATIVE SCAN COUNT
C     KH                OFFSET REQUIRED IN GOES MODE A PROCESSING
C     KOFFSET           OFFSET
C     NSCAN             NUMBER OF SCAN CONTAINING LINES TO BE WRITTEN
C
C   BLOCK DATA-    NONE
C
C   SUBPROGRAMS CALLED-
C     SCALE
C     WLINE
C
C   EXIT STATES-
C
C   RESTRICTIONS-
C
C   ATTRIBUTES- SERIALLY REUSABLE
C
C   COMMENTS-
C
C     SUBROUTINE PRDB REPLACES THE FOLLOWING SUBROUTINES:
C        PRVSDB
C        PRVSDB2N
C        PRVSSM
C        PRIRSM
C        VISWPRD
C        IRWPRD
C
C     SUBROUTINE PRDB HAS NOT BEEN TESTED FOR USE IN THE GENERATION
C     OF FULL RESOLUTION 1 KM BY 1 KM IMAGERY.
C
C***********************************************************************
      DATA VS/.FALSE./,IR/.FALSE./,IR4/.FALSE./
      DATA KH    /0/
      DATA IFIRST,ILAST /0,0/
      DATA IMAX,  JMAX  /0,0/
      DATA NLINE /0/
      DATA KREQ  /1/
      DATA IX    /2/
 
      IB=(SCDNUM-1)*800
      IH=(SCDNUM-1)*400
      IW=(SCDNUM-1)*200
 
      KPRINT = .FALSE.
      IF (SCNNO.EQ.100) KPRINT = .TRUE.
 
      IF (KPRINT) PRINT 3310, FTYPE 
      VS  = FTYPE(1:3).EQ.'VIS'
      IR  = FTYPE(1:2).EQ.'IR'
      IR4 = FTYPE(1:3).EQ.'IR4'
      IF (.NOT.(VS.OR.IR)) GO TO 910
 
      SCANDOC(1:4)='SCAN'
      WRITE(SCANDOC(5:8),'(I4)') BUF0(241:242) !RISCT (ASCII) *
      SCANDOC(09:38)=BUFX(01:030) !GVAR BLOCK HEADER
      SCANDOC(39:58)=BUFX(91:110) !GVAR LINE DOCUMENTATION
      SCANDOC(59:78)=BUFX(91:110) !GVAR LINE DOCUMENTATION (DUPLI.)
      SCANDOC(79:86)=BUF0(121:128) !TIME OF CURRENT HEADER BLOCK
      SCANDOC(87:88)=BUF0(243:244) !AISCT *
 
C     NOTE THAT BUF0 CONSISTS OF 3 IDENTICAL 30-BYTE BLOCK HEADERS
C     FOLLOWED BY THE BLOCK 0 DOCUMENTATION AS DESCRIBED IN SECTION 
C     3.0 OF DLR 504-02-01.  SO THE BLOCK 0 DOCUMENTATION IN BUF0
C     WILL BE OFFSET BY 90 BYTES.

 
C     RETRIEVE THE ABSOLUTE SCAN NUMBER.
      KAISCT = 0
      CALL BRPK (SCANDOC,8,87,KAISCT,8,3,2)
      IF (KPRINT) PRINT 3710, SCNNO,(SCANDOC(II:II+3),II=1,85,4)
      PRINT 3720, KAISCT
 
      IF (KDELTAF.EQ.0) THEN
C        PERFORM INITIALIZATION.
 
C        RETRIEVE THE RELATIVE SCAN COUNT AND COMPUTE THE DIFFERENCE
C        BETWEEN THE RELATIVE SCAN COUNT AND THE ABSOLUTE SCAN NUMBER.
         READ (SCANDOC,'(4x,I4)') KRISCT
         PRINT 3730, KRISCT
         KDELTA = KAISCT - KRISCT
         KDELTAF = 1
 
      ENDIF
 
C     DETERMINE THE SCAN.
      NSCAN = KAISCT - KDELTA
 
C     RETRIEVE THE NUMBER OF LINES / SCAN.
      NLZS = NLIZSC(KF)
 
C     DETERMINE THE REFERENCE LINE.
 
C     NOTE:
C     INACTIVE SUPPLEMENTARY LOGIC PROVIDES FOR THE INSERTION OF
C     KH HEADER RECORDS.
 
      KOFFSET = 0
 
CCC   IF (    ) KOFFSET = KH
 
      NLINE0 = (NSCAN - 1 - KOFFSET) * NLZS
 
      KXDC = 1
 
C        SPECIFY THE LINE (BLOCK) AND SAMPLE INDEX LIMITS.
         IF (VS) THEN
            JMAX =     8
            IMAX = 22000 ! NEW LIMIT
         END IF
         IF (IR) THEN
            JMAX =     2
            IMAX =  5500 ! NEW LIMIT
         END IF
 
C        DETERMINE THE LINE (BLOCK) INCREMENT CORRESPONDING TO
C        THE REQUESTED VERTICAL RESOLUTION.
 
         READ (FRAME(KF)(44:48),'(I5)') JINC
         IF (IR) THEN
C           DIVIDE BY 4 BECAUSE EACH BLOCK CONTAINS 4KM DATA.
C           IF THE REQUESTED RESOLUTION IS 4 KM, USE BOTH IR BLOCKS.
C           IF THE REQUESTED RESOLUTION IS 8 KM OR GREATER, USE JUST
C           THE FIRST OF THE POTENTIALLY TWO IR BLOCKS.)
            JINC = JINC/4
         END IF
 
C        DETERMINE THE SAMPLE INCREMENT CORRESPONDING TO
C        THE REQUESTED HORIZONTAL RESOLUTION.

         READ (FRAME(KF)(39:43),'(I5)') IINC
         IF (IR) THEN
            IINC = IINC/4
         END IF
 
C        GET THE NUMBER OF SAMPLES NEEDED FROM EACH DETECTOR.
         LINELEN = LLILW(KF)
 
C        GET THE FIRST SAMPLE NUMBER.
CCCCC    IF (IR) IFIRST = SCHRCH(IH+38)
         IF (IR) IFIRST = STHB(38)
CCCCC    IF (VS) IFIRST = SCHRCH(IH+40)
         IF (VS) IFIRST = STHB(40)
 
C        COPY THE SCAN DATA (ONE OR MORE LINES) FROM VSDAT OR IRDAT
C        INTO LINEBUF. . .
         LCOUNT = 0
         IF (KPRINT) PRINT 3750, JMAX,JINC
         DO 500 J=1,JMAX,JINC
            ILB = 0
            IF (KPRINT) PRINT 3770, IMAX,IINC
            DO I=IFIRST,IMAX,IINC
               ILB = ILB + 1
               IF(ILB.LE.LINELEN) THEN
CCCCC             IF (VS) LINEBUF(ILB) = VSDAT(I,J)
                  IF (IR) LINEBUF(ILB) = IRDAT(I,J)
               END IF
            END DO
            IF (KPRINT) PRINT 3790, ILB
            ILAST = ILB
 
            IF (KPRINT) THEN
            PRINT 3993, (LINEBUF(II),II= 401, 410)
            PRINT 3993, (LINEBUF(II),II= 901, 910)
            PRINT 3993, (LINEBUF(II),II=1401,1410)
            PRINT 3993, (LINEBUF(II),II=1901,1910)
            PRINT 3993, (LINEBUF(II),II=2401,2410)
            PRINT 3993, (LINEBUF(II),II=2901,2910)
            END IF
 
            IF (IR4) THEN
 
C              TEST SCALING (BG 6/2/94)
C              DUMP THE UNSCALED DATA. . .
C              IF ((J.GT.210).AND.(J.LT.215)) THEN
C                 DO ILB = 1,500
C                    WRITE(97,3510) ILB, LINEBUF(ILB)
C                 END DO
C              END IF
C
C              SCALE THE DATA LINE. . .
               CALL SCALE (LINEBUF,LINELEN) ! *
C
C              TEST SCALING (BG 6/2/94)
C              DUMP THE SCALED DATA. . .
C              IF ((J.GT.210).AND.(J.LT.215)) THEN
C              END IF
C
            END IF
 
            LCOUNT = LCOUNT + 1
            NLINE  = NLINE0 + LCOUNT
            IF (KPRINT) PRINT 3991, LINELEN,NLINE0,NLINE,NLINEE,IOE
            IF (KPRINT) PRINT 3992, (SCANDOC(II:II+3),II=1,197,4)
 
            IF (KPRINT) THEN
            PRINT 3993, (LINEBUF(II),II= 401, 410)
            PRINT 3993, (LINEBUF(II),II= 901, 910)
            PRINT 3993, (LINEBUF(II),II=1401,1410)
            PRINT 3993, (LINEBUF(II),II=1901,1910)
            PRINT 3993, (LINEBUF(II),II=2401,2410)
            PRINT 3993, (LINEBUF(II),II=2901,2910)
            END IF
 
            CALL WLINE (KREQ,ABUF,SCANDOC,LINEBUF,LINELEN,IX,NLINE,
     *                  NLINEE,IOE)
            IF (NLINEE.LT.0) GO TO 930
            IF (IOE.LT.0) GO TO 940
 
  500    CONTINUE
 
      GO TO 990
 
  910 PRINT 3910
      GO TO 990
  920 PRINT 3920
      GO TO 990
  930 PRINT 3930, NLINE,NLINEE
      GO TO 990
  940 PRINT 3940, NLINE,IOE
 
  990 RETURN
 
 3310 FORMAT (' PRDB:       INGEST TYPE ',A4)
C3510 FORMAT (' PRDB:       BEFORE SCALING, I AND LINEBUF(I) ARE: ',2I5)
C3520 FORMAT (' PRDB:       AFTER SCALING, I AND LINEBUF(I) ARE: ',2I5)
 3710 FORMAT (' PRDB:       SCAN ',I4/(' PRDB:       ',10Z9.8))
 3720 FORMAT (' PRDB:       KAISCT ',I4)
 3730 FORMAT (' PRDB:       KRISCT ',I4)
 3750 FORMAT (' PRDB:       JMAX JINC ',2I5)
 3770 FORMAT (' PRDB:       IMAX IINC ',2I5)
 3790 FORMAT (' PRDB:       ILB ',I5)
 3910 FORMAT (' PRDB: UNRECOGNIZED INGEST TYPE')
 3920 FORMAT (' PRDB: UNSUPPORTED PROCESSING REQUEST')
 3930 FORMAT (' PRDB: NLINE =',I5,3X,'NLINEE =',I4)
 3940 FORMAT (' PRDB: NLINE =',I5,3X,'IOE =',I4)
 3991 FORMAT (' PRDB:       LINELEN,NLINE0,NLINE,NLINEE,IOE',5I8)
 3992 FORMAT (' PRDB:       ',10Z9.8)
 3993 FORMAT (' PRDB:       ',10I5)
 
C * ONE OF THE GOALS OF THE CURRENT (08/19/2003) REFORMATTER UPGRADE,
C   WHICH HAS INCLUDED THE CREATION OF THIS SUBROUTINE, HAS BEEN TO
C   CHANGE ONLY AS MUCH OF THE EXISTING CODE AS IS ABSOLUTELY
C   NECESSARY TO ACHIEVE THE DESIRED PERFORMANCE OBJECTIVES.
C   FREQUENTLY A CHANGE IN ONE SUBROUTINE MUST BE ACCOMPANIED BY
C   NUMEROUS CHANGES ELSEWHERE.  SUBROUTINE SCALE HAS BEEN LEFT
C   INTACT.  IT WILL BE USED ONLY WITH IR DATA, AND ITS BUFFER SIZE,
C   15000 INTEGER*2 WORDS, IS MORE THAN ADEQUATE FOR ALL CURRENT
C   AND ENVISIONED DATA IN THE IR SPECTRUM.  R. S.

      END
