      SUBROUTINE RFEPO (RKEY,KUN,NUMREC,LENREC,FM,RECBUF,KRSC,IOS,KST)
C***********************************************************************
C   NAME- RFEPO 
C
C   LANGUAGE- VS FORTRAN  TYPE- SUBROUTINE      COMPUTER- IBM AIX
C
C   VERSION-  2.02  DATE- 10/19/07  PROGRAMMER- SCHREITZ, R.  EC2200
C
C   FUNCTION-
C
C     READS ANY OF THE FOLLOWNG TYPES OF RECORD: 
C        BLOCK 0 DOCUMENTATION RECORD  
C        CHANNEL n IR DATA RECORD (n = 2 THROUGH 6) (v = 8 KM OR 4 KM)
C        VISIBLE DATA RECORD (v = 1 KM).
C
C     n INDICATES THE DETECTOR WAVELENGTH, E. G. 
C        n = 4 CORRESPONDS TO 11 MICRONS.
C     v INDICATES THE VERTICAL OR NORTH/SOUTH RESOLUTION.
C
C   CALLING SEQUENCE PARAMETERS-
C
C     RKEY         C*3  READ KEY 
C                       'DOC'  FOR  BLOCK 0 DOCUMENTATION
C                       'IRn'  FOR  CHANNEL n IR DATA
C                       'VIS'  FOR  VISIBLE DATA
                        CHARACTER*3 RKEY
C     KUN          I*4  UNIT NUMBER
C     NUMREC       I*4  RECORD NUMBER
C     LENREC       I*4  RECORD LENGTH 
C     FM           C*8  RECORD FORMAT 
                        CHARACTER*8 FM
C     RECBUF       C    RECORD BUFFER
                        CHARACTER*10000 RECBUF
C     KRSC         I*4  RELATIVE SCAN COUNT
C     IOS          I*4  IO STATUS PROVIDED BY READ REQUEST   
C                        0 NORMAL COMPLETION
C                       10 REQUESTED RECORD CANNOT BE READ
C                        1 REQUESTED RECORD IS OUT OF RANGE
C     KST          I*4  STATUS INDICATOR                        
C                        0 NORMAL COMPLETION                
C                        1 EXAMINED SEGMENT OF SCAN LINE DOCUMENTATION
C                          SET TO ZERO
C                        2 EXAMINED PARAMETER IN SCAN LINE DOCUMENTATION
C                          OUT OF RANGE
C                        9 READ ERROR - SEE IOS
C
C   COMMON AREA PARAMETERS-
C
      INCLUDE 'rconst.i'
C
C   LOCAL PARAMETERS-
C
C     ISLDOC0      I*2  PORTION OF THE SCAN LINE DOCUMENTATION IN 
C                       RECORD NUMREC IN THE DOCUMENTATION FILE UDOCUF,  
C                       BEGINNING AT THE RELATIVE SCAN COUNT
C                       (12 16-BIT WORDS)   
                        INTEGER*2 ISLDOC0(12)
C     ISLDOCX      I*2  THE SCAN LINE DOCUMENTATION IN RECORD NUMREC 
C                       IN THE DATA FILE UDATAF
C                       (16 10-BIT WORDS)
                        INTEGER*2 ISLDOCX(16)
C
C   SUBPROGRAMS CALLED-
C     BRPK
C
C***********************************************************************

CCC   PRINT 3010, RKEY,NUMREC
  
      READ (KUN,FMT=FM,REC=NUMREC,ERR=900,IOSTAT=IOS) 
     |RECBUF(1:LENREC)
 
C     CHECK FOR MISSING OR INVALID INFORMATION.
      KST = 0
      NZ  = 0
      IF (RKEY.EQ.'DOC') THEN
        CALL BRPK(RECBUF,16,121,ISLDOC0,16,1,12)
        DO I = 1,12
        IF (ISLDOC0(I).NE.0) NZ = 1
        END DO
        IF (NZ.EQ.0) GO TO 950
        KRSC = ISLDOC0(1)
      ELSE 
        CALL BRPK(RECBUF,10,073,ISLDOCX,16,1,16)
        DO I = 1,16
        IF (ISLDOCX(I).NE.0) NZ = 1   
        END DO
        IF (NZ.EQ.0) GO TO 950
CCC     PRINT 9010, ISLDOCX(6),ISLDOCX(7)
        KRSC = 1024*ISLDOCX(6) + ISLDOCX(7)
      END IF      

CCC   PRINT 3020, RKEY,NUMREC,KRSC
      MAX = 2000
      IF (KRSC.GT.MAX) GO TO 970
      GO TO 990
 
  900 KST = 9

      IF (IOS.EQ.10) THEN                         
      PRINT 3910, RKEY,NUMREC        
      GO TO 990
      END IF

      IF (IOS.EQ.1) THEN                               
      PRINT 3920, RKEY,NUMREC    
      GO TO 990
      END IF

      PRINT 3930, RKEY,NUMREC,IOS    
      GO TO 990

  950 KST = 1
      PRINT 3950, RKEY,NUMREC
      GO TO 990

  970 KST = 2
      PRINT 3970, RKEY,NUMREC
      GO TO 990

  990 RETURN

 3010 FORMAT(' RFEPO: READING ',
     |                   A3,' FILE RECORD ',I5.5)
 3020 FORMAT(' RFEPO: ',A3,' FILE RECORD ',I5.5,
     |       ' RELATIVE SCAN COUNT = ',I5.5)     
 3910 FORMAT(' RFEPO: ',A3,' FILE RECORD ',I5.5, 
     |       ' CANNOT BE READ ')
 3920 FORMAT(' RFEPO: ',A3,' FILE RECORD ',I5.5, 
     |       ' IS OUT OF RANGE ')
 3930 FORMAT(' RFEPO: ',A3,' FILE RECORD ',I5.5, 
     |       ' ABNORMAL CONDITION ENCOUNTERED '/
     |       '         IOSTATUS = ',I3.3)
 3950 FORMAT(' RFEPO: ',A3,' FILE RECORD ',I5.5,' CONTAINS',
     |       ' EMPTY DATA FIELDS:')
 3970 FORMAT(' RFEPO: ',A3,' FILE RECORD ',I5.5,' CONTAINS',
     |       ' INVALID DATA:')
 9010 FORMAT(' RFEPO: LDOCN(6),LDOCN(7)',2I6.5)
      END
